param(
    [string]$Trace = "none"
    )

.".\scripts\common.ps1"

$FileExists = (Test-Path "options.log" -PathType Leaf)

 function StartTracing($Option) 
{
    GetOSVersion;

    if($Option -eq "boot") 
    {
        $global:BootTraceOn = $true;
        return;
    }

    if($Option -eq "patch") 
    {
        StartUsbDriverLogging;
        return;
    }

    if($Option -eq "patchlib") 
    {
        StartPatchLibLogging;
        return;
    }

    if($Option -eq "usbbl") 
    {
        StartiBtUsbBootloaderLogging;
        return;
    }

    if ($Option -eq "msusb")
    {
        StartMsUsbLogging;
        return;
    }

    if ($Option -eq "uart")
    {
        StartUartDriverLogging;
        return;
    }

    if ($Option -eq "rfkill")
    {
        if ($global:OSVersion -eq "Win8")
        {
            StartRfKillLogging;
        }
        return;
    }

    if ($Option -eq "audio") 
    {
        if ($global:OSVersion -ne "Win8")
        {
            StartBtAudioLogging;
        }
        return;
    }

    if ($Option -eq "msbt") 
    {
        StartMsBtLogging;  
        return;
    }
    
    if ($Option -eq "siva")
    {
        StartSivaLogging;
        return;
    }

    if ($Option -eq "moto") 
    {
        StartMotorolaCommonLogging;
        return;
    }

    if ($OPtion -eq "profiles")
    {
        StartMotorolaLeHIDLogging;  
        StartMotorolaMediaLogging;  
        StartMotorolaOBEXLogging;  
        return;
    }
}

If (!($FileExists))
{
    $NewPath = "";
    $NewPath = CreateSessionFolder($LogFolderPath)

    $global:LogFilePath = $NewPath[0];

    #Create summary file
    $temp = "$global:LogFilePath\$global:SummaryFile";
    $global:SummaryFile = $temp;

    $Fileexists = Test-Path $global:SummaryFile | Out-Null;

    if($Fileexists -eq $False) 
    {
        New-Item $global:SummaryFile -type file | Out-Null;
    }

    LogMessage($global:Version);

    ProbeHardwareAndSoftware;
   
    $Trace.ToLower();
     
    if ($Trace -eq "none")
    {
        $Trace = $global:DefaultTraces;
    }

    if ($Trace -eq "rfkill") 
    {
        $Trace = $global:RfkillTraces;
    }
    
    if ($Trace -eq "boot") 
    {
        $Trace = $global:BootTraces;
    }
    
    if ($Trace -eq "Sleep")
    {
        $Trace = $global:SleepTraces;
    }
    
    if ($Trace -eq "Hibernate")
    {
        $Trace = $global:HibernateTraces;
    }
    
    if ($Trace -eq "all") 
    {
        $Trace = $global:AllTraces;
    }else
    {
        $temp = $Trace -match "sleep" | Out-Null;

        if ($temp -eq $true)
        {
            $Trace -replace "sleep",$global:SleepTraces | Out-Null;
        } 
        
        $temp = $Trace -match "hibernate";

        if ($temp -eq $true)
        {
            $Trace -replace "hibernate", $global:HibernateTraces | Out-Null;
        }
    }

    New-Item "options.log" -type file | Out-Null

    Add-Content "options.log" $global:LogFilePath | Out-Null;

    LogMessage("Trace options:$Trace");
    
    Probeibtver;
    
    Write-Host "Collecting BT Link Keys"
    ProbeLinkKeys;

    $Trace.Split(" ") | ForEach {
        Add-Content "options.log" $_;
        StartTracing($_);
    }

    write-host ""
    write-host "Reproduce the scenario and then run Tracestop.cmd to stop tracing" -ForegroundColor Yellow
    write-host ""
    write-host "Logs can be found in the folder $global:LogFilePath" -ForegroundColor Green
}else
{
    write-host ""
    write-host "Previous trace sessions were not closed" -ForegroundColor Yellow
    Write-host "Please run Tracestop.cmd" -ForegroundColor Red -BackgroundColor White
 }


